@@ -4,11 +4,11 @@
 
 use std::collections::BTreeMap;
 
-use ruma_identifiers::{RoomAliasId, UserId};
-use ruma_serde::StringEnum;
 use serde::{Deserialize, Serialize};
 
-use crate::{MilliSecondsSinceUnixEpoch, PrivOwnedStr};
+use crate::{
+    serde::StringEnum, MilliSecondsSinceUnixEpoch, OwnedRoomAliasId, OwnedUserId, PrivOwnedStr,
+};
 
 /// Metadata about a third party protocol.
 ///
@@ -89,7 +89,7 @@ pub struct ProtocolInstance {
 
     /// A unique identifier across all instances.
     ///
-    /// See [matrix-doc#3203](https://github.com/matrix-org/matrix-doc/issues/3203).
+    /// See [matrix-spec#833](https://github.com/matrix-org/matrix-spec/issues/833).
     #[cfg(feature = "unstable-pre-spec")]
     pub instance_id: String,
 }
@@ -112,7 +112,7 @@ pub struct ProtocolInstanceInit {
 
     /// A unique identifier across all instances.
     ///
-    /// See [matrix-doc#3203](https://github.com/matrix-org/matrix-doc/issues/3203).
+    /// See [matrix-spec#833](https://github.com/matrix-org/matrix-spec/issues/833).
     #[cfg(feature = "unstable-pre-spec")]
     pub instance_id: String,
 }
@@ -177,7 +177,7 @@ impl From<FieldTypeInit> for FieldType {
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct Location {
     /// An alias for a matrix room.
-    pub alias: Box<RoomAliasId>,
+    pub alias: OwnedRoomAliasId,
 
     /// The protocol ID that the third party location is a part of.
     pub protocol: String,
@@ -189,7 +189,7 @@ pub struct Location {
 impl Location {
     /// Creates a new `Location` with the given alias, protocol and fields.
     pub fn new(
-        alias: Box<RoomAliasId>,
+        alias: OwnedRoomAliasId,
         protocol: String,
         fields: BTreeMap<String, String>,
     ) -> Self {
@@ -202,7 +202,7 @@ impl Location {
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub struct User {
     /// A matrix user ID representing a third party user.
-    pub userid: Box<UserId>,
+    pub userid: OwnedUserId,
 
     /// The protocol ID that the third party user is a part of.
     pub protocol: String,
@@ -213,15 +213,13 @@ pub struct User {
 
 impl User {
     /// Creates a new `User` with the given userid, protocol and fields.
-    pub fn new(userid: Box<UserId>, protocol: String, fields: BTreeMap<String, String>) -> Self {
+    pub fn new(userid: OwnedUserId, protocol: String, fields: BTreeMap<String, String>) -> Self {
         Self { userid, protocol, fields }
     }
 }
 
 /// The medium of a third party identifier.
-///
-/// This type can hold an arbitrary string. To check for formats that are not available as a
-/// documented variant here, use its string representation, obtained through `.as_str()`.
+#[doc = include_str!(concat!(env!("CARGO_MANIFEST_DIR"), "/src/doc/string_enum.md"))]
 #[derive(Clone, Debug, PartialEq, Eq, StringEnum)]
 #[ruma_enum(rename_all = "lowercase")]
 #[non_exhaustive]
